/***************************************************************************
* Copyright (c) Wolf Vollprecht, Sylvain Corlay and Johan Mabille          *
* Copyright (c) QuantStack                                                 *
*                                                                          *
* Distributed under the terms of the BSD 3-Clause License.                 *
*                                                                          *
* The full license is in the file LICENSE, distributed with this software. *
****************************************************************************/

#ifndef XTENSOR_IO_CONFIG_HPP
#define XTENSOR_IO_CONFIG_HPP

#define XTENSOR_IO_VERSION_MAJOR 0
#define XTENSOR_IO_VERSION_MINOR 9
#define XTENSOR_IO_VERSION_PATCH 0

#pragma cling add_library_path("D:/bld/xtensor-io_1576590142849/_h_env/Library/lib64")
#pragma cling add_library_path("D:/bld/xtensor-io_1576590142849/_h_env/Library/lib32")
#pragma cling add_library_path("D:/bld/xtensor-io_1576590142849/_h_env/Library/lib")

#endif
